//
//  RidTestViewController.m
//  RidTest
//
//  Created by aka on 10/07/14.
//  Copyright Masayuki Akamatsu 2010. All rights reserved.
//

#import "RidTestViewController.h"
#import <TargetConditionals.h>

@implementation RidTestViewController

/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
// ビューが読み込まれた時
- (void)viewDidLoad
{
    [super viewDidLoad];
	
	// 外部スクリーン接続のノーティフィケーションを登録
	[[NSNotificationCenter defaultCenter] addObserver:self 
											 selector:@selector(screenDidConnect) 
												 name:UIScreenDidConnectNotification 
											   object:nil];
	
	[[NSNotificationCenter defaultCenter] addObserver:self 
											 selector:@selector(screenDidDisconnect) 
												 name:UIScreenDidDisconnectNotification 
											   object:nil];	
	
	// 外部スクリーンに接続
	[self screenDidConnect];
	
	// アニメーションのためのタイマーを起動
	[NSTimer scheduledTimerWithTimeInterval:0.5 target:self selector:@selector(move:) userInfo:nil repeats:YES];	
	
}

// スクリーンの情報を表示
- (void)showScreenInfo
{
	// 接続されているスクリーンを求める
	NSArray *screens = [UIScreen screens];
	// スクリーンの数を表示
	infoTextView.text = [NSString stringWithFormat:@"Number of Screens: %d", [screens count]];
	
	// すべてのスクリーンについて...
	for (UIScreen *screen in screens)
	{
		// スクリーンの情報を表示
		infoTextView.text = [infoTextView.text stringByAppendingFormat:@"\n\n%@", screen];
		
		// スクリーンがメイン・スクリーンであれば...
		if (screen == [UIScreen mainScreen])
			infoTextView.text = [infoTextView.text stringByAppendingString:@"\n(Main Screen)"];
	}
}

// 外部スクリーンが接続された時
- (void)screenDidConnect
{
	// スクリーンの情報を表示
	[self showScreenInfo];
	
	// 接続されているスクリーンを求める
	NSArray *screens = [UIScreen screens];
	
	
	// すべてのスクリーンについて...
	for (UIScreen *screen in screens)
	{
		// メイン・スクリーンでなければ...
		if (screen != [UIScreen mainScreen])
		{
			// 外部スクリーンであることを表示
			infoTextView.text = [infoTextView.text stringByAppendingString:@"\n(External Screen)"];

			// 対応解像度をもとめる
			NSArray *modes = [screen availableModes];
			// すべての解像度について...
			for (UIScreenMode *mode in modes)
			{
				// 目的とする解像度であれば...
#if (TARGET_IPHONE_SIMULATOR)
				if (mode.size.width == 1024.0 && mode.size.height == 768.0)
#else
				if (mode.size.width == 800.0 && mode.size.height == 600.0)
#endif
				{
					// 外部ウィンドウが開かれていなければ、
					if (exWindow == nil)
					{
						// スクリーンの解像度を設定
						screen.currentMode = mode;
						
						// 外部ウィンドウを開く
						exWindow = [[UIWindow alloc] initWithFrame:CGRectMake(0, 0, mode.size.width, mode.size.height)];
						// 外部ウィンドウの背景色を設定
						exWindow.backgroundColor = [UIColor grayColor];
						// 外部ウィンドウにビューを載せる
						[exWindow addSubview:exView];
						// 外部ウィンドウのスクリーンを設定
						exWindow.screen = screen;
						// 外部ウィンドウを表示
						[exWindow makeKeyAndVisible];
						
						// 外部ウィンドを開いたことを表示
						infoTextView.text = [infoTextView.text stringByAppendingString:@"\n(External Window Shown)"];
					}
				}
			}
		}
	}
}


// 外部スクリーンが接続されなくなった時
- (void)screenDidDisconnect
{
	// スクリーンの情報を表示
	[self showScreenInfo];
	
	// ビューを外部ウィンドウから取り除く
	[exView removeFromSuperview];
	// 外部ウィンドウを解放する
	[exWindow release];
	exWindow = nil;
}

// タイマーから呼び出されるメソッド
- (void)move:(NSTimer *)timer
{
	// アニメーションの定義開始
	[UIView beginAnimations:nil context:nil];
	[UIView setAnimationDuration:0.5];
	
	// アニメーションによって変化させる事柄を設定
	// UFOを移動
	int x = rand() % (int)(exView.frame.size.width);
	int y = rand() % (int)(exView.frame.size.height);
	ufoView.center = CGPointMake(x, y);
	
	// アニメーションの定義終了、実行
	[UIView commitAnimations];
}

/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [super dealloc];
}

@end
